window.Gleam.initSearch([{"doc":"parallel_map","title":"parallel_map","content":"# parallel_map\r\n\r\n[![Package Version](https://img.shields.io/hexpm/v/parallel_map)](https://hex.pm/packages/parallel_map)\r\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/parallel_map/)\r\n\r\nNote: This package only works for the erlang target.\r\n\r\nThis is a simple gleam library that adds a `yielder_pmap` and `list_pmap`,\r\nwhich has a similar behaviour and interface as `yielder.map` (from `gleam/yielder`) and `list.map` (from the standard library),\r\nexcept it runs in parallel by spawning extra processes to do the work.\r\n\r\nThere is also `yielder_find_pmap` and `list_find_pmap` which stop the whole\r\nparallel execution after finding the first **Ok** value.\r\n\r\n```sh\r\ngleam add parallel_map\r\n```\r\n```gleam\r\nimport gleam/list\r\nimport gleam/yielder\r\nimport gleam/result\r\nimport parallel_map.{MatchSchedulers, WorkerAmount}\r\n\r\npub fn main() {\r\n  let map_func = fn(a: Int) -&gt; Int {a * a}\r\n\r\n  let yielder_input = yielder.range(0, 1000)\r\n\r\n  yielder_input\r\n  |&gt; yielder.map(map_func)\r\n\r\n  // can be rewritten as\r\n  yielder_input\r\n  |&gt; parallel_map.yielder_pmap(map_func, WorkerAmount(16), 100)\r\n  |&gt; yielder.map(result.unwrap(_, -1))\r\n\r\n  let list_input = list.range(0, 1000)\r\n\r\n  list_input\r\n  |&gt; list.map(map_func)\r\n\r\n  // can be rewritten as\r\n  list_input\r\n  |&gt; parallel_map.list_pmap(map_func, MatchSchedulersOnline, 100)\r\n  |&gt; list.map(result.unwrap(_, -1))\r\n\r\n\r\n  // there is also\r\n  //   parallel_map.yielder_find_pmap similar to yielder.find_map\r\n  //   parallel_map.list_find_pmap similar to list.find_map,\r\n  // which stop the works after finding the first Ok value.\r\n\r\n  let find_map_func = fn(a: Int) -&gt; Result(Int, Int) {\r\n    case a {\r\n      x if x &gt; 500 -&gt; Ok(x * 2)\r\n      _ -&gt; Error(a)\r\n    }\r\n  }\r\n\r\n  yielder_input\r\n  |&gt; yielder.find_map(find_map_func)\r\n\r\n  // can be rewritten as\r\n  yielder_input\r\n  |&gt; parallel_map.yielder_find_pmap(find_map_func, WorkerAmount(16), 100)\r\n\r\n\r\n  list_input\r\n  |&gt; list.find_map(find_map_func)\r\n\r\n  // can be rewritten as\r\n  list_input\r\n  |&gt; parallel_map.list_find_pmap(find_map_func, MatchSchedulersOnline, 100)\r\n}\r\n```\r\n\r\nFurther documentation can be found at &lt;https://hexdocs.pm/parallel_map&gt;.\r\n\r\n## Development\r\n\r\n```sh\r\ngleam run   # Run the project\r\ngleam test  # Run the tests\r\ngleam shell # Run an Erlang shell\r\n```\r\n","url":"index.html"},{"doc":"parallel_map","title":"WorkerAmount","content":"pub type WorkerAmount {\n  WorkerAmount(value: Int)\n  MatchSchedulersOnline\n}\n This type is used to specify the number of workers to spawn\nWorkerAmount(value: Int)\n will spawn that number of workers\n\nMatchSchedulersOnline\n will spawn workers to match the amount of\n schedulers currently online\n\nSynonyms:\nparallel_map.WorkerAmount\nparallel_map WorkerAmount","url":"parallel_map.html#WorkerAmount"},{"doc":"parallel_map","title":"list_find_pmap","content":"pub fn list_find_pmap(\n  input: List(a),\n  mapping_func: fn(a) -&gt; Result(b, c),\n  num_workers: WorkerAmount,\n  timeout_milliseconds: Int,\n) -&gt; Result(b, Nil)\n This function behaves similarly to gleam_stdlib&#39;s list.find_map\nSynonyms:\nparallel_map.list_find_pmap\nparallel_map list_find_pmap","url":"parallel_map.html#list_find_pmap"},{"doc":"parallel_map","title":"list_pmap","content":"pub fn list_pmap(\n  input: List(a),\n  mapping_func: fn(a) -&gt; b,\n  num_workers: WorkerAmount,\n  timeout_milliseconds: Int,\n) -&gt; List(Result(b, Nil))\n This function behaves similarly to gleam_stdlib&#39;s yielder.map\n\n Returns a new list containing only the elements of the first list\n after the function has been applied to each one, with the resulting value\n wrapped in a Result\n\n If the timeout specified is exceeded while attempting\n to collect the result of the computation, the value will instead be Error(Nil)\nSynonyms:\nparallel_map.list_pmap\nparallel_map list_pmap","url":"parallel_map.html#list_pmap"},{"doc":"parallel_map","title":"yielder_find_pmap","content":"pub fn yielder_find_pmap(\n  input: Yielder(a),\n  mapping_func: fn(a) -&gt; Result(b, c),\n  num_workers: WorkerAmount,\n  timeout_milliseconds: Int,\n) -&gt; Result(b, Nil)\n This function behaves similarly to gleam_stdlib&#39;s yielder.find_map\nSynonyms:\nparallel_map.yielder_find_pmap\nparallel_map yielder_find_pmap","url":"parallel_map.html#yielder_find_pmap"},{"doc":"parallel_map","title":"yielder_pmap","content":"pub fn yielder_pmap(\n  input: Yielder(a),\n  mapping_func: fn(a) -&gt; b,\n  num_workers: WorkerAmount,\n  timeout_milliseconds: Int,\n) -&gt; Yielder(Result(b, Nil))\n This function behaves similarly to gleam/yielder&#39;s yielder.map\n\n Creates an yielder from an existing yielder and a transformation function\n\n Each element in the new yielder will be the result of calling the given\n function on the elements in the given yielder, with the resulting value\n wrapped in a Result\n\n If the timeout specified is exceeded while attempting\n to collect the result of the computation, the element will instead be Error(Nil)\n\n This function also differs from yielder.map in that it will spawn the workers\n and perform the computation right when it is called,\n but it does not attempt to collect the result until the yielder is later run\nSynonyms:\nparallel_map.yielder_pmap\nparallel_map yielder_pmap","url":"parallel_map.html#yielder_pmap"},{"doc":"parallel_map","title":"parallel_map","content":"","url":"parallel_map.html"}]);